/*
 *	(c) copyright 2003-2004 Amichai Rothman
 *
 *	This file is part of the Java TNEF package.
 *
 *	The Java TNEF package is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	The Java TNEF package is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package net.freeutils.tnef;

/**
 * The <code>Address</code> class encapsulates an address
 * used in some TNEF message attributes.
 *
 * @author  Amichai Rothman
 * @since	2003-04-25
 */
public class Address {

	String displayName;
	String address;
	String type;

	/**
	 * Constructs an empty Address.
	 */
	 public Address() {
	 }

	/**
	 * Constructs an Address using the given TNEF stream bytes.
	 * 
	 * @param data the TNEF stream bytes to parse address from
	 */
	public Address(byte[] data) {
		int displayNameLength = TNEFUtils.getU16(data,0);
		this.displayName = TNEFUtils.createString(data,2,displayNameLength);
		int addressLength = TNEFUtils.getU16(data,2 + displayNameLength);
		String typeAndAddress = TNEFUtils.createString(data,4 + displayNameLength,addressLength);
		int separator = typeAndAddress.indexOf(':');
		this.type = typeAndAddress.substring(0,separator);
		this.address = typeAndAddress.substring(separator+1);
	}

	/**
	 * Constructs a Address containing the specified values.
	 * 
	 * @param displayName the display name associated with address
	 * @param type the address type
	 * @param address the address
	 */
	public Address(String displayName, String type, String address) {
		this.displayName = displayName;
		this.type = type;
		this.address = address;
	}

	/**
	 * Gets the Address display name.
	 * 
	 * @return the Address display name.
	 */
	public String getDisplayName() {
		return this.displayName;
	}

	/**
	 * Gets the address.
	 * 
	 * @return the address.
	 */
	public String getAddress() {
		return this.address;
	}

	/**
	 * Gets the Address type.
	 * 
	 * @return the Address type.
	 */
	public String getType() {
		return this.type;
	}

	/**
	 * Returns a string representation of this object.
	 * 
	 * @return a string represenation of this object.
	 */
	public String toString() {
		return new StringBuffer()
			.append('"')
			.append(getDisplayName())
			.append("\" [")
			.append(getType())
			.append(':')
			.append(getAddress())
			.append(']')
			.toString();
	}

}
